<?php

$LANG = array(

# install.php
'L_INSTALL_TITLE'					=> 'Installation',
'L_WRONG_PHP_VERSION'				=> 'PluXml requiert PHP 5 ou supérieur pour fonctionner.',
'L_SELECT_LANG'						=> 'Sélectionnez votre langue',
'L_INPUT_CHANGE'					=> 'Changer',
'L_DEFAULT_CATEGORY_TITLE'			=> 'Rubrique 1',
'L_DEFAULT_CATEGORY_URL'			=> 'rubrique-1',
'L_DEFAULT_STATIC_TITLE'			=> 'Statique 1',
'L_DEFAULT_STATIC_URL'				=> 'statique-1',
'L_DEFAULT_ARTICLE_TITLE'			=> 'Premier article',
'L_DEFAULT_ARTICLE_URL'				=> 'premier-article',
'L_DEFAULT_COMMENT_CONTENT'			=> 'Ceci est un premier commentaire !',
'L_ERR_PLUXML_ALREADY_INSTALLED'	=> 'PluXml est déjà configuré !',
'L_ERR_MISSING_USER'				=> 'Veuillez renseigner le nom du rédacteur !',
'L_ERR_MISSING_LOGIN'				=> 'Veuillez renseigner le login de connexion !',
'L_ERR_MISSING_PASSWORD'			=> 'Veuillez renseigner un mot de passe !',
'L_ERR_PASSWORD_CONFIRMATION'		=> 'Confirmation du mot de passe incorrecte !',
'L_PLUXML_INSTALLATION'				=> 'Installation de PluXml',
'L_SITE_DESCRIPTION'				=> 'Blog ou Cms à l\'Xml !',
'L_VERSION'							=> 'version',
'L_USERNAME'						=> 'Nom de l\'administrateur',
'L_LOGIN'							=> 'Identifiant de connexion à l\'administration',
'L_PASSWORD'						=> 'Mot de passe',
'L_PASSWORD_CONFIRMATION'			=> 'Confirmation du mot de passe',
'L_INPUT_INSTALL'					=> 'Installer',
'L_TIMEZONE'						=> 'Fuseau horaire',
'L_PWD_VERY_WEAK'					=> 'Mot de passe très faible',
'L_PWD_WEAK'						=> 'Mot de passe faible',
'L_PWD_GOOD'						=> 'Mot de passe bon',
'L_PWD_STRONG'						=> 'Mot de passe fort',
);
?>
